/*
 * geoLines.h - structures and procedures to manipulate
 *   geoLines (arrays of geoPoints) and geoLineArrays (arrays of geoLines)
 *
 * Copyright (C) 1999 Gordon D. Carrie
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 * 
 * Please address questions and bug reports to gcarri@mail.txcyber.com
 *
 ********************************************
 *
 */

#ifndef _GEOLINES_H_
#define _GEOLINES_H_

#include "geography.h"

/* Opaque pointers.  The structs are declared in GeoLines.c */
typedef struct GeoLineStrc *GeoLine;
typedef struct GeoLineArrayStrc *GeoLineArray;

/* Global functions for geoLines */
void InitGeoLine(struct GeoLineStrc *geoLine);
GeoLine NewGeoLine(unsigned nptsMax);
void ClearGeoLine(GeoLine geoLine);
int GrowGeoLine(GeoLine geoLine, unsigned nptsMax);
int AppendGeoPoint(GeoPoint geoPoint, GeoLine geoLine);
unsigned GeoLineNPts(GeoLine geoLine);
unsigned GeoLineNPtsMax(GeoLine geoLine);
double GeoLineOrdMax(GeoLine geoLine);
double GeoLineOrdMin(GeoLine geoLine);
double GeoLineAbsMax(GeoLine geoLine);
double GeoLineAbsMin(GeoLine geoLine);
GeoPoint GetGeoPoint(GeoLine geoLine, unsigned n);
void FreeGeoLine(GeoLine geoLine);
CartPoint GeoLineCtr(GeoLine geoLine);
int GeoLineContainGeoPoint(GeoPoint geopt, GeoLine geoln);

/* Global functions for geoLineArrays */
GeoLineArray NewGeoLineArray(unsigned nLinesMax);
int GrowGeoLineArray(GeoLineArray lineArray, unsigned nLinesMax);
void GeoLineArrayAddUser(GeoLineArray geoLineArray);
void GeoLineArrayDropUser(GeoLineArray geoLineArray);
int AppendGeoLine(GeoLine geoLine, GeoLineArray geoLineArray);
int GeoLineArrayContainGeoPoint(GeoPoint geopt,
  struct GeoLineArrayStrc *geoLnArr);
unsigned GeoLineArrayNLines(GeoLineArray geoLineArray);
unsigned GeoLineArrayNLinesMax(GeoLineArray geoLineArray);
unsigned GeoLineArrayNPts(GeoLineArray geoLineArray);
unsigned GeoLineArrayNmax(GeoLineArray geoLineArray);
double GeoLineArrayOrdMax(GeoLineArray geoLineArray);
double GeoLineArrayOrdMin(GeoLineArray geoLineArray);
double GeoLineArrayAbsMax(GeoLineArray geoLineArray);
double GeoLineArrayAbsMin(GeoLineArray geoLineArray);
unsigned GeoLineArrayUserCnt(GeoLineArray geoLineArray);
GeoLine GetGeoLine(GeoLineArray geoLineArray, unsigned n);
void FreeGeoLineArray(GeoLineArray lineArray);

#endif
