/*
 * geoProj.h - cartographic projections
 *
 * Copyright (C) 1999 Gordon D. Carrie
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 * 
 * Please address questions and bug reports to gcarri@mail.txcyber.com
 *
 ********************************************
 *
 */

#ifndef _GEOPROJ_H_
#define _GEOPROJ_H_

#include "geography.h"
#include "geoLines.h"

/* Opaque pointer to projection struct */
typedef struct Projection *Projection;

/* Functions to initialize projections */
void
SetCylEqdist(struct Projection *proj, double rlon);

void
SetCylEqArea(struct Projection *proj, double rlon);

void
SetMercator(struct Projection *proj, double rlon);

void
SetLambertConfConic(struct Projection *proj, double rlat, double rlon);

void
SetPolarStereographic(struct Projection *proj, enum LatSgn ns);

void
SetSinusoidalProj(struct Projection *proj, double rlon);

void
SetOrthographic(struct Projection *proj, GeoPoint rpt);

/* Manipulate projections */
Projection
AllocProj();

void
FreeProj(Projection proj);

double
GeoProjGetScale(Projection proj);

void
GeoProjSetScale(Projection proj, double scale);

double
GeoProjGetRotation(Projection proj);

void
GeoProjSetRotation(Projection proj, double rotation);

char *
ProjDescriptor(Projection proj);

/* Conversion from and to projection */
GeoPoint
ProjToLatLon(GeoPoint projPoint, Projection proj);

GeoPoint
LatLonToProj(GeoPoint latLon, Projection proj);

GeoLineArray
LatLonArrayToProj(GeoLineArray latLonArray, Projection proj);

#endif
